@@ -37,7 +37,7 @@ def correct(data_frame, baseline_frame, column):
     return data
 
 
-def baseline_load(file_path: str, columns_to_use=None):
+def baseline_load(file_path: str, columns_to_use):
     baselines = os.listdir(file_path)
     baseline_dataframes = {}
     for file in baselines:
@@ -73,14 +73,22 @@ def wl_ext(frame, wavelength):
     return extracted_frame
 
 
-def load_dsc(path, baseline_path=None, rms=False, wavelengths=None):
+def load_dsc(path, baseline_path=None, rms=False, wavelengths=None, ms_offset=None):
     some_dict = defaultdict()
     for method, data_list in path.items():
         gradient_files = data_list.get("gradient", [])
         isotherm_files = data_list.get("isotherm", [])
 
-        gradient_args = {"data": gradient_files, "method": method}
-        isotherm_args = {"data": isotherm_files, "method": method}
+        gradient_args = {
+            "data": gradient_files,
+            "method": method,
+            "ms_offset": ms_offset,
+        }
+        isotherm_args = {
+            "data": isotherm_files,
+            "method": method,
+            "ms_offset": ms_offset,
+        }
 
         if method == "STA":
             gradient_args["columns"] = [
@@ -137,7 +145,7 @@ def helper(**kwargs):
     rms = kwargs.get("rms")
     columns_to_use = kwargs.get("columns")
     baseline = kwargs.get("baseline_path")
-
+    ms_offset = kwargs.get("ms_offset")
     topic_pattern = r"\\(Topic.*?)\\"
     frame_dictionary = {}
 
@@ -146,13 +154,13 @@ def helper(**kwargs):
         topic_name, name = naming(file, topic_pattern)
 
         if method == "IR":
-            data_frame = ir_runner(file, wavelength, rms)
+            data_frame = ir_runner(file, rms, wavelength)
 
         if method == "STA":
-            data_frame = sta_runner(baseline, columns_to_use, file)
+            data_frame = sta_runner(file, columns_to_use, baseline)
 
         if method == "MS":
-            data_frame = ms_runner(file)
+            data_frame = ms_runner(file, ms_offset)
 
         if method == "MS":
             ion = os.path.splitext(file.split("\\")[-1])[0]
@@ -167,24 +175,31 @@ def helper(**kwargs):
     return frame_dictionary
 
 
-def ms_runner(file):
+def ms_runner(file, ms_offset=None, norm=True):
     data_frame = pd.read_table(
-        file, sep="\s+", header=None, names=["Time", "Absorbance"], index_col="Time"
+        file, sep="\s+", header=None, names=["Time", "Abundance"], index_col="Time"
     )
+    if ms_offset:
+        data_frame.index = data_frame.index.astype(float).map(
+            lambda x: x - (ms_offset / 60)
+        )
+        data_frame = data_frame[data_frame.index >= 0]
     data_frame["Absorbance"] = data_frame["Absorbance"].ewm(span=5).mean()
-    data_frame = series_normalizer(data_frame)
+    if norm:
+        data_frame = series_normalizer(data_frame)
     return data_frame
 
 
-def sta_runner(baseline, columns_to_use, file):
+def sta_runner(file, columns_to_use, baseline=None):
     data_frame = pd.read_csv(
         file, engine="python", usecols=columns_to_use, index_col="Time"
     )
     sta = percentage(data_frame, ["Unsubtracted Weight"])
     sta.rename(columns={"Unsubtracted Weight": "Percent Weight"}, inplace=True)
-    baseline_frames = baseline_load(baseline, columns_to_use)
     method, isograd, temperature = mit_extract(file)
     isograd = isograd.lower()
+
+    baseline_frames = baseline_load(baseline, columns_to_use)
     if temperature.isdigit():
         corrective_frame = baseline_frames.get(
             isograd, {temperature: pd.DataFrame()}
@@ -210,7 +225,7 @@ def mit_extract(file):
     return method, isograd, temperature
 
 
-def ir_runner(file, wavelength, rms):
+def ir_runner(file, rms, wavelength):
 
     if rms:
         data_frame = pd.read_csv(file, engine="python", header=2, index_col=0).dropna()
@@ -245,19 +260,3 @@ def naming(file, topic_pattern=r"\\(Topic.*?)\\"):
 def series_normalizer(data_frame):
     data_frame = (data_frame - data_frame.min()) / (data_frame.max() - data_frame.min())
     return data_frame
-
-
-def asym_peak(t, pars):
-    "from Anal. Chem. 1994, 66, 1294-1301"
-    a0 = pars[0]  # peak area
-    a1 = pars[1]  # elution time
-    a2 = pars[2]  # width of gaussian
-    a3 = pars[3]  # exponential damping term
-    f = (
-        a0
-        / 2
-        / a3
-        * np.exp(a2 ** 2 / 2.0 / a3 ** 2 + (a1 - t) / a3)
-        * (erf((t - a1) / (np.sqrt(2.0) * a2) - a2 / np.sqrt(2.0) / a3) + 1.0)
-    )
-    return f
