@@ -24,7 +24,7 @@ def main():
         with open(parameters, "r") as stream:
             data_loaded = yaml.safe_load(stream)
     except FileNotFoundError as e:
-        data_loaded = aiyaml.write_yaml()
+        data_loaded = aiyaml.write_acd_thermal_yaml()
         with open("project parameters.yaml", "w") as outfile:
             yaml.dump(data_loaded, outfile, default_flow_style=False)
         print("Please fill out the project parameters.yaml document")
@@ -43,28 +43,24 @@ def decompress(data_loaded):
     wavelengths = data_loaded.get("WAVE LENGTHS")
     rms = data_loaded.get("RMS")
     root = data_loaded.get("DIRECTORY")
-
+    ms_offset = data_loaded.get("MS Deadtime (Seconds)")
     directory_listing, method_listing, temperature_listing = aifile.topic_directories(
         root
     )
 
-    return (
-        method_listing,
-        temperature_listing,
-        root,
-        wavelengths,
-        rms,
-    )
+    return (method_listing, temperature_listing, root, wavelengths, rms, ms_offset)
 
 
-def _run(method_listing, temperature_listing, root, wavelengths, rms):
+def _run(method_listing, temperature_listing, root, wavelengths, rms, ms_offset):
 
     gradient_temp = temperature_listing.get("gradient", [])
     isotherm_temp = temperature_listing.get("isotherm", [])
 
     baseline_path = os.path.join(root, "Parameter\\Baseline\\")
 
-    all_frames = aithermal.load_dsc(method_listing, baseline_path, rms, wavelengths)
+    all_frames = aithermal.load_dsc(
+        method_listing, baseline_path, rms, wavelengths, ms_offset
+    )
 
     tracer = []
     for method, data in all_frames.items():
